#[non_exhaustive]pub struct DistBus {Show 16 fields
pub id: String,
pub terminals: Vec<String>,
pub grounded: Vec<String>,
pub v_min: Option<f64>,
pub v_max: Option<f64>,
pub vpn_min: Option<Vec<f64>>,
pub vpn_max: Option<Vec<f64>>,
pub vpp_min: Option<Vec<f64>>,
pub vpp_max: Option<Vec<f64>>,
pub vpos_min: Option<f64>,
pub vpos_max: Option<f64>,
pub vneg_max: Option<f64>,
pub vzero_max: Option<f64>,
pub vn_max: Option<f64>,
pub location: Option<Location>,
pub extras: Extras,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Stringterminals: Vec<String>Ordered terminal names; OpenDSS node numbers as strings.
grounded: Vec<String>Terminals tied to ground with zero impedance.
v_min: Option<f64>Voltage magnitude bounds, volts: the scalar pair plus the phase to neutral and phase to phase families, and the per-sequence scalars (BMOPF schema 0.1.0: positive sequence has both bounds, negative and zero sequence and neutral to ground are magnitude caps whose lower bound is always 0).
v_max: Option<f64>vpn_min: Option<Vec<f64>>vpn_max: Option<Vec<f64>>vpp_min: Option<Vec<f64>>vpp_max: Option<Vec<f64>>vpos_min: Option<f64>vpos_max: Option<f64>vneg_max: Option<f64>vzero_max: Option<f64>vn_max: Option<f64>location: Option<Location>Optional bus coordinates in the network coordinate space.
extras: ExtrasImplementations