#[non_exhaustive]pub struct PowerFactorControl {
pub pf: f64,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pf: f64Trait Implementations
Sourceimpl Clone for PowerFactorControl
impl Clone for PowerFactorControl
Sourcefn clone(&self) -> PowerFactorControl
fn clone(&self) -> PowerFactorControl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerFactorControl
impl Debug for PowerFactorControl
Sourceimpl<'de> Deserialize<'de> for PowerFactorControl
impl<'de> Deserialize<'de> for PowerFactorControl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PowerFactorControl
impl JsonSchema for PowerFactorControl
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PowerFactorControl
impl PartialEq for PowerFactorControl
Sourceimpl Serialize for PowerFactorControl
impl Serialize for PowerFactorControl
impl StructuralPartialEq for PowerFactorControl