#[non_exhaustive]pub struct VoltVarControl {
pub voltage_reference: Option<ControlVoltageReference>,
pub breakpoints: Vec<f64>,
pub q_limits: Vec<f64>,
pub q_unit: Option<ReactivePowerUnit>,
pub q_ref: Option<ReactivePowerReference>,
pub p_min_for_q: Option<f64>,
pub p_min_for_q_max: Option<f64>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.voltage_reference: Option<ControlVoltageReference>breakpoints: Vec<f64>q_limits: Vec<f64>q_unit: Option<ReactivePowerUnit>q_ref: Option<ReactivePowerReference>p_min_for_q: Option<f64>p_min_for_q_max: Option<f64>Trait Implementations
Sourceimpl Clone for VoltVarControl
impl Clone for VoltVarControl
Sourcefn clone(&self) -> VoltVarControl
fn clone(&self) -> VoltVarControl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoltVarControl
impl Debug for VoltVarControl
Sourceimpl<'de> Deserialize<'de> for VoltVarControl
impl<'de> Deserialize<'de> for VoltVarControl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VoltVarControl
impl JsonSchema for VoltVarControl
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VoltVarControl
impl PartialEq for VoltVarControl
Sourceimpl Serialize for VoltVarControl
impl Serialize for VoltVarControl
impl StructuralPartialEq for VoltVarControl