#[non_exhaustive]pub struct VoltWattControl {
pub voltage_reference: Option<ControlVoltageReference>,
pub breakpoints: Vec<f64>,
pub p_limits: Vec<f64>,
pub p_unit: Option<ActivePowerUnit>,
pub p_ref: Option<ActivePowerReference>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.voltage_reference: Option<ControlVoltageReference>breakpoints: Vec<f64>p_limits: Vec<f64>p_unit: Option<ActivePowerUnit>p_ref: Option<ActivePowerReference>Trait Implementations
Sourceimpl Clone for VoltWattControl
impl Clone for VoltWattControl
Sourcefn clone(&self) -> VoltWattControl
fn clone(&self) -> VoltWattControl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VoltWattControl
impl Debug for VoltWattControl
Sourceimpl<'de> Deserialize<'de> for VoltWattControl
impl<'de> Deserialize<'de> for VoltWattControl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VoltWattControl
impl JsonSchema for VoltWattControl
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VoltWattControl
impl PartialEq for VoltWattControl
Sourceimpl Serialize for VoltWattControl
impl Serialize for VoltWattControl
impl StructuralPartialEq for VoltWattControl